@@ -1,6 +1,9 @@
 package App::Git::Perl;
 
-our $VERSION = '0.1.10';
+our $VERSION = '0.1.11';
+
+use strict;
+use warnings;
 
 =head1 NAME
 
@@ -16,7 +19,8 @@ Nedzad Hrnjica
 
 =head1 LICENSE
 
- Perl License (perl)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
